referees

# XMLRésuméLibrary: User Guide

referee | Element Reference | result

## Name

referees — Contains one or more referees

## Synopsis

### Content Model

    (referee+)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `referees` element groups together one or more `referee` elements.

### Parents

`referees` may be contained in these elements: `resume`

## Examples

    <referees>
      <referee>
        <name>Mr. Samuel J. Black</name>
        <contact>
          <phone>555.555.1212</phone>
        </contact>
      </referee>
      <referee>
        <name>Mom</name>
        <contact>
          <email>my_mommy@moms.bob</email>
        </contact>
      </referee>
      <referee>
        <name>Dad</name>
      </referee>
    </referees>

referee | Element Reference | result